from django.conf import settings
from django.http import HttpRequest


def env_badge(request: HttpRequest):
    return {
        "ADMIN_ENV_NAME": getattr(settings, "ADMIN_ENV_NAME", None),
        "ADMIN_ENV_COLOR": getattr(settings, "ADMIN_ENV_COLOR", "#22FE00"),
        'ADMIN_ENV_ICON': getattr(settings, 'ADMIN_ENV_ICON', ''), 
    }



from django.apps import AppConfig


class DjangoAdminEnvBadgeConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = "django_admin_env_badge"
    verbose_name = "Admin Environment Badge"